[gnome-shell] Give user 48ms to read each character of a PAM message, earlier it was 16ms



commit 88973857146f91acd3b633234afa2c2bb358392a
Author: Sarvjeet <princeghotra0011 gmail com>
Date:   Fri Mar 20 15:42:37 2015 +0530

    Give user 48ms to read each character of a PAM message, earlier it was 16ms
    
    User read time per character has been changed from 16ms to 48ms because the
    message of information about last login is displayed for half a sec that is not
    a good user experience. So time to read a character is increased to 48ms from 16ms.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=720885

 js/gdm/util.js |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/js/gdm/util.js b/js/gdm/util.js
index 6286b84..2ff59cb 100644
--- a/js/gdm/util.js
+++ b/js/gdm/util.js
@@ -35,8 +35,8 @@ const ALLOWED_FAILURES_KEY = 'allowed-failures';
 const LOGO_KEY = 'logo';
 const DISABLE_USER_LIST_KEY = 'disable-user-list';
 
-// Give user 16ms to read each character of a PAM message
-const USER_READ_TIME = 16
+// Give user 48ms to read each character of a PAM message
+const USER_READ_TIME = 48
 
 const MessageType = {
     NONE: 0,


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]